/**
 * @file playfld.h
 * @mainpage
 *
 * STE PLAYFIELD ROUTINES
 * allow AHCC to have access to an independent playfield screen
 * with STE hardware scrolling and a split screen (panel) with
 * different palette
 *
 * (c) 2007/2008/2012 by Simon Sunnyboy / Paradize
 * based upon Scrolly STE Screen technology
 *
 * Special acknowledge to Klapauzius and Nicolas Pomarede for the split stabilizer!
 *
 * STE/F030 only!
 * @copyright
 * FREE FOR ALL, USE AT AND IMPROVE ON YOUR OWN RISK!
 */

#ifndef PLAYFLD_H_INCLUDED
#define PLAYFLD_H_INCLUDED

	/**
	 * describes a screen including STE hardware scrolling parameters.
	 *
	 * linewid contains the number of words to be appended on the current scanline.
	 * hscroll contains the bit shift offset 0-15 to show
	 */
	typedef struct STEPlayfield_t
	{
		void *start_of_screen;		/**< start address of screen in memory */
		unsigned short palette[16];	/**< STE compatible palette to display for the screen */
		unsigned char linewid;		/**< STE linewid register contents for the screen */
		unsigned char hscroll;      /**< STE hscroll register contents for the screen */
	} STEPlayfield_t;

	/**
	 * initializes the STE Playfield routines and sets up the split.
	 *
	 * The upper and lower screens are shown at the specified scanline +1.
	 * E.q. setting this to 99 will show both screens halfway.
	 * This is necessary for stabilization of the split which has to wait for one scanline
	 * for the exact border to switch the video parameters over.
	 */
	void STEPlayfield_Install(unsigned char scanline_for_split);

	/**
	 * uninstalls the current STE Playfield setup and returns to the former screen setup.
	 */
	void STEPlayfield_Uninstall(void);

	/**
	 * internal position of scanline to perform the split.
	 *
	 * Made accessible to allow dynamic configuration of the split location.
	 */
	extern volatile unsigned char STEPlayfield_SplitLocation;

	/**
	 * holds the data for the upper screen to show including palette.
	 *
	 * The data is allocated by the STE Playfield kernel.
	 */
	extern volatile STEPlayfield_t STEPlayfield_UpperScreen;

	/**
	 * holds the data for the lower screen to show including palette.
	 *
	 * The data is allocated by the STE Playfield kernel.
	 */
	extern volatile STEPlayfield_t STEPlayfield_LowerScreen;

#endif // PLAYFLD_H_INCLUDED
